@@ -10,7 +10,7 @@ import (
 )
 
 // CtxKeyQuiet is the context key to mute the chain.
-var CtxKeyQuiet = struct{ quiet bool }{quiet: true}
+var CtxKeyQuiet = struct{ key string }{key: "quiet"}
 
 // errNonFatal is a non fatal error
 type errNonFatal struct {
@@ -77,6 +77,8 @@ type ActiveCommandChain struct {
 	funcs     []cFunc
 	lastStage string
 	log       *log.Entry
+
+	executing bool
 }
 
 // Logger returns the logger for the command chain.
@@ -89,6 +91,10 @@ func (a *ActiveCommandChain) Add(f func() error) {
 
 // Stage sets the current stage of the runner.
 func (a *ActiveCommandChain) Stage(s string) {
+	if a.executing {
+		a.log.Println(s, "...")
+		return
+	}
 	a.funcs = append(a.funcs, cFunc{s: s})
 }
 
@@ -101,7 +107,10 @@ func (a *ActiveCommandChain) Stagef(format string, s ...interface{}) {
 // Exec executes the command chain.
 // The first errored function terminates the chain and the
 // error is returned. Otherwise, returns nil.
-func (a ActiveCommandChain) Exec() error {
+func (a *ActiveCommandChain) Exec() error {
+	a.executing = true
+	defer func() { a.executing = false }()
+
 	for _, f := range a.funcs {
 		if f.f == nil {
 			if f.s != "" {
