@@ -134,10 +134,12 @@ var startCmdArgs struct {
 		Edit                    bool
 		Editor                  string
 		ActivateRuntime         bool
+		Binfmt                  bool
 		DNSHosts                []string
 		Foreground              bool
 		SaveConfig              bool
 		LegacyCPU               int // for backward compatibility
+		Template                bool
 	}
 }
 
@@ -170,6 +172,7 @@ func init() {
 	startCmd.Flags().BoolVarP(&startCmdArgs.Flags.Foreground, "foreground", "f", false, "Keep colima in the foreground")
 	startCmd.Flags().StringVar(&startCmdArgs.Hostname, "hostname", "", "custom hostname for the virtual machine")
 	startCmd.Flags().StringVarP(&startCmdArgs.DiskImage, "disk-image", "i", "", "file path to a custom disk image")
+	startCmd.Flags().BoolVar(&startCmdArgs.Flags.Template, "template", false, "use the template file for initial configuration")
 
 	// retain cpu flag for backward compatibility
 	startCmd.Flags().IntVar(&startCmdArgs.Flags.LegacyCPU, "cpu", defaultCPU, "number of CPUs")
@@ -200,7 +203,7 @@ func init() {
 	}
 
 	// binfmt
-	startCmd.Flags().BoolVar(&startCmdArgs.Binfmt, "binfmt", true, binfmtDesc)
+	startCmd.Flags().BoolVar(&startCmdArgs.Flags.Binfmt, "binfmt", true, binfmtDesc)
 
 	// config
 	startCmd.Flags().BoolVarP(&startCmdArgs.Flags.Edit, "edit", "e", false, "edit the configuration file before starting")
@@ -397,6 +400,7 @@ func prepareConfig(cmd *cobra.Command) {
 	startCmdArgs.Mounts = mountsFromFlag(startCmdArgs.Flags.Mounts)
 	startCmdArgs.Network.DNSHosts = dnsHostsFromFlag(startCmdArgs.Flags.DNSHosts)
 	startCmdArgs.ActivateRuntime = &startCmdArgs.Flags.ActivateRuntime
+	startCmdArgs.Binfmt = &startCmdArgs.Flags.Binfmt
 
 	// handle legacy kubernetes-disable
 	for _, disable := range startCmdArgs.Flags.LegacyKubernetesDisable {
@@ -408,13 +412,21 @@ func prepareConfig(cmd *cobra.Command) {
 
 	// if there is no existing settings
 	if current.Empty() {
-		// attempt template
-		template, err := configmanager.LoadFrom(templateFile())
-		if err != nil {
-			// use default config if there is no template or existing settings
+		templateUsed := false
+
+		// attempt template if enabled
+		if startCmdArgs.Flags.Template {
+			template, err := configmanager.LoadFrom(templateFile())
+			if err == nil {
+				current = template
+				templateUsed = true
+			}
+		}
+
+		if !templateUsed {
+			// use default config if there is no template or template is disabled
 			return
 		}
-		current = template
 	}
 
 	// set missing defaults in the current config
@@ -489,6 +501,11 @@ func prepareConfig(cmd *cobra.Command) {
 			startCmdArgs.ActivateRuntime = current.ActivateRuntime
 		}
 	}
+	if !cmd.Flag("binfmt").Changed {
+		if current.Binfmt != nil {
+			startCmdArgs.Binfmt = current.Binfmt
+		}
+	}
 	if !cmd.Flag("network-host-addresses").Changed {
 		startCmdArgs.Network.HostAddresses = current.Network.HostAddresses
 	}
