@@ -18,7 +18,7 @@ import (
 
 const (
 	Name           = "kubernetes"
-	DefaultVersion = "v1.31.2+k3s1"
+	DefaultVersion = "v1.33.3+k3s1"
 
 	ConfigKey = "kubernetes_config"
 )
@@ -104,6 +104,12 @@ func (c *kubernetesRuntime) Provision(ctx context.Context) error {
 		conf = c.config()
 	}
 
+	if conf.Version == "" {
+		// this ensure if `version` tag in `kubernetes` section in yaml is empty,
+		// it should assign with the `DefaultVersion` for the baseURL
+		conf.Version = DefaultVersion
+	}
+
 	if c.isVersionInstalled(conf.Version) {
 		// runtime has changed, ensure the required images are in the registry
 		if currentRuntime := c.runtime(); currentRuntime != "" && currentRuntime != runtime {
@@ -246,9 +252,7 @@ func (c kubernetesRuntime) Teardown(ctx context.Context) error {
 
 	// k3s is buggy with external containerd for now
 	// cleanup is manual
-	a.Add(func() error {
-		return c.deleteAllContainers()
-	})
+	a.Add(c.deleteAllContainers)
 
 	c.teardownKubeconfig(a)
 
